@@ -1188,11 +1188,6 @@ bool BitBoard::fromGoodFen(const QString& qfen, bool chess960)
             return false;
         }
         m_moveNumber = fen.mid(i).toInt();
-        while(c >= '0' && c <= '9')
-        {
-            c = fen[++i];
-        }
-
         if(m_moveNumber == 0)
         {
             // Silently fix illegal movenumber
@@ -1449,7 +1444,7 @@ int BitBoard::chess960Pos() const
     bool n0f = false;
     bool n1f = false;
     int rf = 0;
-    int n0s[] = { 0,4,7,9 };
+    const int n0s[] = { 0,4,7,9 };
     for (Square square=a1; square<=h1; ++square)
     {
         if (pieceAt(square) == WhiteQueen)
@@ -2621,7 +2616,7 @@ bool BitBoard::HasRookForCastling(int index) const
     {
         x = getFirstBitAndClear64<Square>(cr);
     }
-    return (m_rooks & SetBit(x));
+    return (x<64) ? (m_rooks & SetBit(x)) : 0;
 }
 
 Square BitBoard::CastlingRook(int index) const
@@ -3246,7 +3241,7 @@ QString BitBoard::toHumanFen() const
             w.append(charLists[p].join(","));
         }
     }
-    for(Piece p = BlackKing; p != Empty; ++p)
+    for(Piece p = BlackKing; p != Empty; ++p) // After BlackPawn there comes Empty!
     {
         if(charLists.contains(p))
         {
