@@ -10,10 +10,8 @@
 
 #include <QtDebug>
 #include <QFile>
-#include "annotation.h"
+#include <utility>
 #include "gamecursor.h"
-#include "settings.h"
-#include "tags.h"
 
 using namespace chessx;
 
@@ -26,7 +24,6 @@ GameCursor::GameCursor()
     : m_currentBoard(new BoardX)
     , m_nodes()
     , m_currentNode(0)
-    , m_startPly(0)
     , m_startingBoard()
 {
     m_startingBoard.setStandardPosition();
@@ -37,7 +34,6 @@ GameCursor::GameCursor(const GameCursor& rhs)
     : m_currentBoard(new BoardX)
     , m_nodes(rhs.m_nodes)
     , m_currentNode(rhs.m_currentNode)
-    , m_startPly(rhs.m_startPly)
     , m_startingBoard(rhs.m_startingBoard)
 {
     if (rhs.m_currentBoard)
@@ -52,7 +48,6 @@ GameCursor& GameCursor::operator=(const GameCursor& rhs)
     {
         m_nodes = rhs.m_nodes;
         m_currentNode = rhs.m_currentNode;
-        m_startPly = rhs.m_startPly;
         m_startingBoard = rhs.m_startingBoard;
         if (m_currentBoard && rhs.m_currentBoard)
         {
@@ -69,7 +64,8 @@ GameCursor::~GameCursor()
 
 void GameCursor::initCursor()
 {
-    m_nodes.append(Node());
+    Node n = Node();
+    m_nodes.append(n);
     if (m_currentBoard)
     {
         m_currentNode = ROOT_NODE;
@@ -94,7 +90,6 @@ void GameCursor::clear()
 {
     m_nodes.clear();
     m_startingBoard.setStandardPosition();
-    m_startPly = 0;
     initCursor();
 }
 
@@ -103,7 +98,6 @@ void GameCursor::clear(const QString& fen, bool chess960)
     m_nodes.clear();
     m_startingBoard.setChess960(chess960);
     m_startingBoard.fromFen(fen);
-    m_startPly = (m_startingBoard.moveNumber() - 1) * 2 + (m_startingBoard.toMove() == Black);
     initCursor();
 }
 
@@ -125,6 +119,11 @@ MoveId GameCursor::makeNodeIndex(MoveId moveId) const
     {
         moveId = m_nodes[m_currentNode].nextNode;
     }
+    else if (moveId == PARENT_MOVE)
+    {
+        MoveId p = m_nodes[m_currentNode].parentNode;
+        moveId = (p != NO_MOVE) ? p : m_nodes[m_currentNode].previousNode;
+    }
     bool rangeOk = 0 <= moveId && moveId < m_nodes.size();
     if (!rangeOk || m_nodes[moveId].Removed())
     {
@@ -210,7 +209,7 @@ bool GameCursor::atLineEnd(MoveId moveId) const
     MoveId node = makeNodeIndex(moveId);
     if (node == NO_MOVE)
     {
-        return false;
+        node = ROOT_NODE;
     }
     return m_nodes[node].nextNode == NO_MOVE;
 }
@@ -255,11 +254,26 @@ int GameCursor::moveNumber(MoveId moveId) const
     MoveId node = makeNodeIndex(moveId);
     if(node != NO_MOVE)
     {
-        if(int plyNum = plyNumber(node))
-        {
-            return (m_startPly + plyNum - 1) / 2 + 1;
-        }
-        return 0;
+        int plyNum = plyNumber(node)-1;
+        if (m_startingBoard.blackToMove()) plyNum++;
+        return (m_startingBoard.moveNumber()+(plyNum/2));
+    }
+    return -1;
+}
+
+int GameCursor::nextMoveNumber(bool atStartOfLine, bool atEndOfLine) const
+{
+    int select = CURRENT_MOVE;
+    if (atEndOfLine && !atStartOfLine)
+        select = CURRENT_MOVE;
+    else if (atStartOfLine)
+        select = PARENT_MOVE;
+    MoveId node = makeNodeIndex(select);
+    if(node != NO_MOVE)
+    {
+        int plyNum = plyNumber(node);
+        if (m_startingBoard.blackToMove()) plyNum++;
+        return (m_startingBoard.moveNumber()+(plyNum/2));
     }
     return -1;
 }
@@ -503,7 +517,7 @@ void GameCursor::remove(MoveId moveId, QList<MoveId>* removed)
     {
         removed->append(node);
     }
-    for (auto v: qAsConst(m_nodes[node].variations))
+    for (auto v: std::as_const(m_nodes[node].variations))
     {
         remove(v, removed);
     }
@@ -525,7 +539,7 @@ void GameCursor::truncateFrom(MoveId moveId, QList<MoveId>* removed)
     if (node == NO_MOVE)
         return;
     remove(m_nodes[node].nextNode, removed);
-    for (auto v: qAsConst(m_nodes[node].variations))
+    for (auto v: std::as_const(m_nodes[node].variations))
     {
         remove(v, removed);
     }
@@ -664,7 +678,7 @@ bool GameCursor::removeVariation(MoveId variation)
 
     QList<MoveId> &vars = m_nodes[m_currentNode].variations;
     int n = vars.indexOf(variation);
-    vars.removeAt(n);
+    if (n>=0) vars.removeAt(n);
     return true;
 }
 
@@ -688,40 +702,8 @@ void GameCursor::removeNullLines()
         if (node.Removed()) continue;
         if (node.move.isNullMove())
         {
-            if (node.nextNode == NO_MOVE)
-            {
-                int self = iw-m_nodes.begin();
-                if (node.parentNode == node.previousNode)
-                {
-                    // This is the first move of an empty variation
-                    MoveId parentNode = m_nodes[self].parentNode;
-                    remove(self);
-                    QList<MoveId> &vars = m_nodes[parentNode].variations;
-                    int n = vars.indexOf(self);
-                    vars.removeAt(n);
-                 }
-                else
-                {
-                    MoveId previousNode = m_nodes[self].previousNode;
-                    QList<MoveId> &vars = m_nodes[previousNode].variations;
-                    if (vars.isEmpty())
-                    {
-                        // This is an empty move at the end of a line
-                        m_nodes[previousNode].nextNode = NO_MOVE;
-                        node.remove();
-                    }
-                    else
-                    {
-                        // There are siblings - swap with first sibling and remove
-                        MoveId parentNode = m_nodes[self].parentNode;
-                        int variation = vars.at(0);
-                        reparentVariation(variation, parentNode);
-                        node.remove();
-                        m_nodes[previousNode].nextNode = variation;
-                        vars.removeAt(0);
-                    }
-                }
-            }
+            int self = iw-m_nodes.begin();
+            removeVariation(self);
         }
     }
 }
@@ -855,6 +837,7 @@ void GameCursor::dumpMoveNode(MoveId moveId) const
         qDebug() << "   Move        : " << m_nodes.at(moveId).move.toAlgebraic()
                  << " (" << m_nodes.at(moveId).move.rawMove()
                  << ", " << m_nodes.at(moveId).move.rawUndo()
+                 << ", " << m_nodes.at(moveId).Ply()
                  << ")";
     }
 }
