@@ -80,10 +80,13 @@ public :
     };
     enum AnnotationFilter
     {
-        FilterNone = 0x00,
-        FilterTan  = 0x01,
-        FilterCan  = 0x02,
-        FilterEval = 0x04,
+        FilterNone    = 0x00,
+        FilterTan     = 0x01,
+        FilterCan     = 0x02,
+        FilterTanCan  = (FilterTan | FilterCan),
+        FilterEval    = 0x04,
+        FilterTanEval = (FilterTan | FilterEval),
+        FilterCanEval = (FilterCan | FilterEval),
         FilterAll  = (FilterTan | FilterCan | FilterEval),
     };
 
@@ -128,7 +131,7 @@ public :
     /** @return arrowAnnotation at move at node @p moveId. */
     QString arrowAnnotation(MoveId moveId = CURRENT_MOVE) const;
     /** @return annotation at move at node @p moveId. */
-    QString specAnnotation(const QRegularExpression &r, MoveId moveId = CURRENT_MOVE) const;
+    QString specAnnotation(const QRegularExpression &r, MoveId moveId = CURRENT_MOVE, QString *found=0) const;
     /** @return time annotation (either egt or clock) at move at node @p moveId. */
     QString timeAnnotation(MoveId moveId = CURRENT_MOVE, Position position = AfterMove) const;
     void setTimeAnnotation(QString annotation, MoveId moveId = CURRENT_MOVE);
@@ -379,6 +382,8 @@ public :
     void setNeedsCleanup(bool value);
 
     bool needsCleanup() const;
+    /** Removes the node at @p moveId */
+    void removeNode(MoveId moveId = CURRENT_MOVE);
 
 protected:
     /** Find the point in the this game where @p otherGame fits in the next time.
@@ -386,8 +391,7 @@ protected:
     MoveId findMergePoint(const GameX &otherGame);
     /** Find the next illegal position in all variations and mainline moves after the current position, and cut the game from there */
     void truncateVariationAfterNextIllegalPosition();
-    /** Removes the node at @p moveId */
-    void removeNode(MoveId moveId = CURRENT_MOVE);
+
 
     void dbIndicateAnnotationsOnBoard();
     bool positionRepetition(const BoardX &board);
