@@ -15,6 +15,7 @@
 #include <QTextStream>
 #include "board.h"
 #include "output.h"
+#include "gameid.h"
 #include "memorydatabase.h"
 #include "settings.h"
 #include "tags.h"
@@ -303,10 +304,10 @@ QString Output::writeMove(MoveToWrite moveToWrite)
     // Read comments
     if(m_game.canHaveStartAnnotation(moveId))
         precommentString = isPgnType(m_outputType) ? m_game.annotation(moveId, GameX::BeforeMove) :
-                           m_game.textAnnotation(moveId, GameX::BeforeMove, m_game.textFilter2());
+                           m_game.textAnnotation(moveId, GameX::BeforeMove, m_game.textFilter());
 
     QString commentString = isPgnType(m_outputType) ? m_game.annotation(moveId) :
-                                                    m_game.textAnnotation(moveId, GameX::AfterMove, m_game.textFilter2());
+                                                    m_game.textAnnotation(moveId, GameX::AfterMove, m_game.textFilter());
 
     // Write precomment if any
     text += writeComment(precommentString, mvno, Precomment);
@@ -506,7 +507,8 @@ QString Output::writeMainLine(MoveId upToNode)
             m_dirtyBlack = true;
             m_game.dbMoveToId(m_game.parentMove());
         }
-        m_game.forward();
+        if (!m_game.forward())
+            break; // Just make sure we get out in case something went wrong
     } while(!m_game.atLineEnd());
 
     return text;
@@ -862,7 +864,8 @@ void Output::outputUtf8(QTextStream& out, FilterX& filter)
     postProcessOutput(header);
     out << header;
 
-    for(int i = 0; i < filter.count(); ++i)
+    QList<GameId> filterList = filter.selectedGames();
+    foreach(GameId i, filterList)
     {
         if(filter.database()->loadGame(i, game))
         {
@@ -895,7 +898,8 @@ void Output::outputLatin1(QDataStream& out, FilterX& filter)
     QByteArray b = header.toLatin1();
     out.writeRawData(b, b.length());
 
-    for(int i = 0; i < filter.count(); ++i)
+    QList<GameId> filterList = filter.selectedGames();
+    foreach(GameId i, filterList)
     {
         if(filter.database()->loadGame(i, game))
         {
