@@ -669,6 +669,10 @@ void PgnDatabase::splitTokenList(QVector<QStringRef>& list)
             case '.': // Count dots to figure out which side is moving.
             if (!dots)
             {
+                if (m_currentLine[start].isDigit())
+                {
+                    list.push_back(QStringRef(&m_currentLine, start, n-1)); // Current move counter
+                }
                 start += (n-1);
                 n = 1;
             }
@@ -685,7 +689,7 @@ void PgnDatabase::splitTokenList(QVector<QStringRef>& list)
                     if (!c.isLetterOrNumber() && (c!='.'))
                     {
                         // It's a token, not part of a move
-                        if (n>1) list.push_back(t);
+                        list.push_back(t);
                         start += (n-1);
                         n = 1;
                         inNag = true;
@@ -818,16 +822,23 @@ void PgnDatabase::parseLine(GameX* game)
 
 inline void PgnDatabase::parseMoveToken(GameX* game, QString token)
 {
+    QChar c = token.at(0);
+    if (c.isDigit())
+    {
+        moveNumberFound = token.toInt();
+        return;
+    }
+
     if (token.startsWith("..."))
     {
         white = false;
-        found = true;
+        dotFound = true;
         token.remove(0,3);
     }
     else if (token.startsWith("."))
     {
         white = true;
-        found = true;
+        dotFound = true;
         token.remove(0,1);
     }
 
@@ -835,8 +846,8 @@ inline void PgnDatabase::parseMoveToken(GameX* game, QString token)
 
     if(m_newVariation)
     {
-        bool dummyNeeded = found && (((white && game->board().whiteToMove()) ||
-                                     (!white && game->board().blackToMove())));
+        bool dummyNeeded = dotFound && (((white && game->board().whiteToMove()) ||
+                                         (!white && game->board().blackToMove())));
         if (dummyNeeded)
         {
             if (!game->move(game->currentMove()).isDummyMove())
@@ -859,6 +870,7 @@ inline void PgnDatabase::parseMoveToken(GameX* game, QString token)
     else
     {
         m_variation = game->dbAddSanMove(token, QString());
+
         if(!m_precomment.isEmpty())
         {
             game->dbSetAnnotation(m_precomment, m_variation, GameX::BeforeMove);
@@ -867,7 +879,17 @@ inline void PgnDatabase::parseMoveToken(GameX* game, QString token)
         }
     }
 
-    found = false;
+    if (dotFound && AppSettings->getValue("/General/strictMoveCounter").toBool() && ( m_variation != NO_MOVE ))
+    {
+        int currentMoveNumber = game->moveNumber();
+        if (currentMoveNumber != moveNumberFound)
+        {
+            game->removeNode();
+            m_variation = NO_MOVE;
+        }
+    }
+
+    dotFound = false;
 }
 
 void PgnDatabase::parseToken(GameX* game, const QStringRef& token)
