@@ -43,6 +43,8 @@ signals:
     void actionRequested(const EditAction& action);
     void queryActiveGame(const GameX** game);
     void signalMergeGame(GameId gameIndex, QString source);
+    void swipeRight();
+    void swipeLeft();
 
 private:
     void configureFont();
