@@ -47,6 +47,7 @@
 #include <QFontDatabase>
 #include <QImageReader>
 #include <QSpinBox>
+#include <QLabel>
 #include <QMenu>
 #include <QMenuBar>
 #include <QTextCodec>
@@ -131,6 +132,11 @@ TextEdit::TextEdit(QWidget *parent, QMenu *menu)
     fileNew();
 }
 
+TextEdit::~TextEdit()
+{
+    tb->clear();
+}
+
 void TextEdit::setupDocumentActions()
 {
     connect(textEdit->document(), SIGNAL(modificationChanged(bool)),
@@ -152,7 +158,7 @@ void TextEdit::setupDocumentActions()
 
 void TextEdit::setupFileActions(QMenu* xmenu)
 {
-    QToolBar *tb = new QToolBar(this);
+    tb = new QToolBar(this);
     tb->setObjectName("ScrpFileActions");
     tb->setWindowTitle(tr("File Actions"));
     addToolBar(tb);
@@ -379,7 +385,7 @@ void TextEdit::setupStyleActions()
     addToolBarBreak(Qt::TopToolBarArea);
     addToolBar(tb);
 
-    QComboBox* comboStyle = new QComboBox(tb);
+    comboStyle = new QComboBox(tb);
     tb->addWidget(comboStyle);
     comboStyle->addItem("Standard");
     comboStyle->addItem("Bullet List (Disc)");
@@ -611,7 +617,7 @@ void TextEdit::textBold()
 {
     QTextCharFormat fmt;
     fmt.setFontWeight(actionTextBold->isChecked() ? QFont::Bold : QFont::Normal);
-    fmt.setBackground(Qt::white);
+    //fmt.setBackground(Qt::white);
     mergeFormatOnWordOrSelection(fmt);
 }
 
@@ -619,7 +625,7 @@ void TextEdit::textUnderline()
 {
     QTextCharFormat fmt;
     fmt.setFontUnderline(actionTextUnderline->isChecked());
-    fmt.setBackground(Qt::white);
+    //fmt.setBackground(Qt::white);
     mergeFormatOnWordOrSelection(fmt);
 }
 
@@ -627,7 +633,7 @@ void TextEdit::textItalic()
 {
     QTextCharFormat fmt;
     fmt.setFontItalic(actionTextItalic->isChecked());
-    fmt.setBackground(Qt::white);
+    //fmt.setBackground(Qt::white);
     mergeFormatOnWordOrSelection(fmt);
 }
 
@@ -635,7 +641,7 @@ void TextEdit::textFamily(const QString &f)
 {
     QTextCharFormat fmt;
     fmt.setFontFamilies(QStringList()<<f);
-    fmt.setBackground(Qt::white);
+    //fmt.setBackground(Qt::white);
     mergeFormatOnWordOrSelection(fmt);
 }
 
@@ -646,7 +652,7 @@ void TextEdit::textSize(const QString &p)
     {
         QTextCharFormat fmt;
         fmt.setFontPointSize(pointSize);
-        fmt.setBackground(Qt::white);
+        //fmt.setBackground(Qt::white);
         mergeFormatOnWordOrSelection(fmt);
     }
 }
@@ -705,7 +711,7 @@ void TextEdit::textStyle(int styleIndex)
         }
 
         listFmt.setStyle(style);
-        listFmt.setBackground(Qt::white);
+        //listFmt.setBackground(Qt::white);
         cursor.createList(listFmt);
 
         cursor.endEditBlock();
@@ -715,7 +721,7 @@ void TextEdit::textStyle(int styleIndex)
         // TODO: The list style cannot be removed at the moment
         QTextBlockFormat bfmt;
         bfmt.setObjectIndex(-1);
-        bfmt.setBackground(Qt::white);
+        //bfmt.setBackground(Qt::white);
         cursor.setBlockFormat(bfmt);
     }
 }
@@ -727,7 +733,7 @@ void TextEdit::textColor()
         return;
     QTextCharFormat fmt;
     fmt.setForeground(col);
-    fmt.setBackground(Qt::white);
+    //fmt.setBackground(Qt::white);
     mergeFormatOnWordOrSelection(fmt);
     colorChanged(col);
 }
@@ -862,10 +868,11 @@ bool PasteTextEdit::eventFilter(QObject *obj, QEvent *event)
 
 void PasteTextEdit::keyPressEvent(QKeyEvent* event)
 {
+    if (!event) return;
     // Pressing Return is ignored
-    if(event && event->type() == QEvent::KeyRelease &&
-            (event->key() == Qt::Key_Return ||
-            event->key() == Qt::Key_Enter))
+    if(event->type() == QEvent::KeyRelease &&
+        (event->key() == Qt::Key_Return ||
+         event->key() == Qt::Key_Enter))
     {
         QKeyEvent event2(QEvent::KeyPress, Qt::Key_Return, Qt::NoModifier);
         QTextEdit::keyPressEvent(&event2);
@@ -978,7 +985,7 @@ void PasteTextEdit::dropImage(const QUrl& url, const QImage& image)
         imageFormat.setWidth( image.width() );
         imageFormat.setHeight( image.height() );
         imageFormat.setName( url.toString() );
-        imageFormat.setBackground(Qt::white);
+        //imageFormat.setBackground(Qt::white);
         textCursor().insertImage(imageFormat);
     }
 }
